@@ -6,6 +6,7 @@
 #' @param width Width of the plot in pixels
 #' @param palette Color of the bar and target line, defaults to `c("grey", "red")`, can use named colors or hex colors. Must be of length two, and the first color will always be used as the bar color.
 #' @param palette_col An additional column that contains specific colors for the bar colors themselves. Defaults to NULL which skips this argument.
+#' @importFrom stats na.omit
 #' @return An object of class `gt_tbl`.
 #' @export
 #'
@@ -29,22 +30,30 @@
 #' @family Themes
 #' @section Function ID:
 #' 3-7
-gt_plt_bullet <- function(gt_object, column = NULL, target = NULL, width = 65,
-                          palette = c("grey", "red"), palette_col = NULL) {
+gt_plt_bullet <- function(
+  gt_object,
+  column = NULL,
+  target = NULL,
+  width = 65,
+  palette = c("grey", "red"),
+  palette_col = NULL
+) {
   stopifnot("'gt_object' must be a 'gt_tbl', have you accidentally passed raw data?" = "gt_tbl" %in% class(gt_object))
   stopifnot("'palette' must be 2 colors" = length(palette) == 2)
 
   # extract the values from specified columns
   all_vals <- gt_index(gt_object, {{ column }})
+  target_vals <- gt_index(gt_object, {{ target }})
 
   if (length(all_vals) == 0) {
     return(gt_object)
   }
 
-  max_val <- max(all_vals, na.rm = TRUE)
-  length_val <- length(all_vals)
+  # provide a forced zero baseline - needed for small value ranges
+  rng_val <- range(c(all_vals, target_vals), na.rm = TRUE)
+  if (all(na.omit(all_vals) >= 0)) rng_val <- c(0, max(rng_val))
 
-  target_vals <- gt_index(gt_object, {{ target }})
+  length_val <- length(all_vals)
 
   col_bare <- gt_index(gt_object, {{ column }}, as_vector = FALSE) %>%
     dplyr::select({{ column }}) %>%
@@ -68,13 +77,15 @@ gt_plt_bullet <- function(gt_object, column = NULL, target = NULL, width = 65,
           }
 
           if (is.na(target_vals)) {
-            stop("Target Column not coercible to numeric, please create and supply an unformatted column ahead of time with gtExtras::gt_duplicate_columns()",
+            stop(
+              "Target Column not coercible to numeric, please create and supply an unformatted column ahead of time with gtExtras::gt_duplicate_columns()",
               call. = FALSE
             )
           }
 
           if (is.na(vals)) {
-            stop("Column not coercible to numeric, please create and supply an unformatted column ahead of time with gtExtras::gt_duplicate_columns()",
+            stop(
+              "Column not coercible to numeric, please create and supply an unformatted column ahead of time with gtExtras::gt_duplicate_columns()",
               call. = FALSE
             )
           }
@@ -82,12 +93,14 @@ gt_plt_bullet <- function(gt_object, column = NULL, target = NULL, width = 65,
           plot_out <- ggplot(data = NULL, aes(x = vals, y = factor("1"))) +
             geom_col(width = 0.1, color = bar_pal, fill = bar_pal) +
             geom_vline(
-              xintercept = target_vals, color = tar_pal, linewidth = 1.5,
+              xintercept = target_vals,
+              color = tar_pal,
+              linewidth = 1.5,
               alpha = 0.7
             ) +
             geom_vline(xintercept = 0, color = "black", linewidth = 1) +
             theme_void() +
-            coord_cartesian(xlim = c(0, max_val)) +
+            coord_cartesian(xlim = rng_val) +
             scale_x_continuous(expand = expansion(mult = c(0, 0.15))) +
             scale_y_discrete(expand = expansion(mult = c(0.1, 0.1))) +
             theme_void() +
@@ -99,13 +112,19 @@ gt_plt_bullet <- function(gt_object, column = NULL, target = NULL, width = 65,
             )
 
           out_name <- file.path(tempfile(
-            pattern = "file", tmpdir = tempdir(),
+            pattern = "file",
+            tmpdir = tempdir(),
             fileext = ".svg"
           ))
 
-          ggsave(out_name,
-            plot = plot_out, dpi = 25.4, height = 5, width = width,
-            units = "mm", device = "svg"
+          ggsave(
+            out_name,
+            plot = plot_out,
+            dpi = 25.4,
+            height = 5,
+            width = width,
+            units = "mm",
+            device = "svg"
           )
 
           img_plot <- readLines(out_name) %>%
